@@ -4,28 +4,29 @@ StarsAlign
 
 A package for aligning and diffing astronomical images.
 
+Specially developed for aligning and comparing float32 images with a large intensity range typically found in astronomical imaging.
+
 This package contains functions that align two single channel images using SIFT and FLANN based matcher, and return the difference image.
 
 Example:
-
-    >>> import numpy as
+===
+    >>> import numpy as np
     >>> import starsalign
-
-    >>> ref_image = np.load('images/ref_image.npy')
-    >>> science_image = np.load('images/science_image.npy')
-
+    >>> ref_image = np.load('ref_image.npy')
+    >>> science_image = np.load('science_image.npy')
     >>> diff_image = starsalign.diff_images(ref_image, science_image)
-
     >>> aligned_image = starsalign.align_images(ref_image, science_image)
 """
 
-__version__ = "1.0.5"
+__version__ = "1.0.6"
 
 import cv2 as cv
 import numpy as np
 
 def align_images(ref_image: np.ndarray, science_image: np.ndarray) -> np.ndarray:
     """
+    align_images()
+    ===
     Aligns the science_image to the reference image by finding keypoints and matching them using SIFT algorithm, then finds the homography between the two images, and applies a perspective warp to align the science_image.
     
     Parameters:
@@ -34,6 +35,11 @@ def align_images(ref_image: np.ndarray, science_image: np.ndarray) -> np.ndarray
         
     Returns:
         np.ndarray: The aligned science image.
+    
+    Example:
+    ===
+    >>> import starsalign
+    >>> aligned_image = starsalign.align_images(ref_image, science_image)
     """
     ref_image_uint8 = np.interp(ref_image, (ref_image.min(), ref_image.max()), (0, 255)).astype(np.uint8)
     science_image_uint8 = np.interp(science_image, (science_image.min(), science_image.max()), (0, 255)).astype(np.uint8)
@@ -71,6 +77,8 @@ def align_images(ref_image: np.ndarray, science_image: np.ndarray) -> np.ndarray
 
 def diff_images(ref_image: np.ndarray, science_image: np.ndarray) -> np.ndarray:
     """
+    diff_images()
+    ===
     Computes the difference between two single channel images by first aligning them and then subtracting them.
 
     Parameters:
@@ -79,6 +87,11 @@ def diff_images(ref_image: np.ndarray, science_image: np.ndarray) -> np.ndarray:
 
     Returns:
         np.ndarray: The result of the subtraction between the aligned science image and the reference image.
+
+    Example:
+    ===
+    >>> import starsalign
+    >>> diff_image = starsalign.diff_images(ref_image, science_image)
     """
     aligned_image = align_images(ref_image, science_image)
     diff_image = ref_image - aligned_image
